GertecResponse class

Constructors

GertecResponse({required String message, required bool success, required dynamic content})
GertecResponse.fromJson(String source)
factory
GertecResponse.fromMap(Map<String, dynamic> map)
factory

Properties

content → dynamic
final
hashCode → int
The hash code for this object.
no setteroverride
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final

Methods

copyWith({String? message, bool? success, dynamic content}) → GertecResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant GertecResponse other) → bool
The equality operator.
override