GertecText class

Constructors

GertecText({required String text, FontSize fontSize = FontSize.NORMAL, PrintAlign algin = PrintAlign.LEFT, bool? bold, bool? underline, bool? wordwrap, int? lineHeight, int? letterSpacing, int? marginLeft})

Properties

algin ↔ PrintAlign
getter/setter pair
bold ↔ bool?
getter/setter pair
fontSize ↔ FontSize
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
letterSpacing ↔ int?
getter/setter pair
lineHeight ↔ int?
getter/setter pair
marginLeft ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final
underline ↔ bool?
getter/setter pair
wordwrap ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited