GertecPrinter class

Constructors

GertecPrinter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cutPaper(CutPaperType type) → Future<GertecResponse>
finishTransaction() → Future<GertecResponse>
getPlatformVersion() → Future<GertecResponse>
line({String ch = '-', int len = 31}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBarCode({int width = 200, int height = 60, required String text, PrintAlign align = PrintAlign.LEFT}) → Future<GertecResponse>
printerState() → Future<GertecResponse>
printImage({required Uint8List image, PrintAlign align = PrintAlign.LEFT}) → Future<GertecResponse>
printQrcode({int width = 100, int height = 100, required String text}) → Future<GertecResponse>
printRaw(Uint8List data) → Future<GertecResponse>
printText(GertecText textObject) → Future<GertecResponse>
readCamera({DecodeMode decodeMode = DecodeMode.MODE_SINGLE_SCAN_CODE}) → Future<GertecResponse>
startTransaction() → Future<GertecResponse>
stopCamera() → Future<GertecResponse>
toString() → String
A string representation of this object.
inherited
wrap({int len = 1}) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited