MethodChannelGertecPrinter class

An implementation of GertecPrinterPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cutPaper(CutPaperType type) → Future<String?>
override
finishTransaction() → Future<String?>
override
getPlatformVersion() → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBarCode({required int width, required int height, required String text, required int align}) → Future<String?>
override
printerState() → Future<String?>
override
printImage(Uint8List image, int align) → Future<String?>
override
printQrcode({required int width, required int height, required String text}) → Future<String?>
override
printRaw(Uint8List data) → Future<String?>
override
printText(GertecText textObject) → Future<String?>
override
readCamera({DecodeMode decodeMode = DecodeMode.MODE_SINGLE_SCAN_CODE}) → Future<String?>
override
startTransaction() → Future<String?>
override
stopCamera() → Future<String?>
override
toString() → String
A string representation of this object.
inherited
wrapLine(int lines) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited