GertecPrinterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • GertecPrinterPlatform
Implementers

Constructors

GertecPrinterPlatform()
Constructs a GertecPrinterPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cutPaper(CutPaperType type) → Future<String?>
finishTransaction() → Future<String?>
getPlatformVersion() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBarCode({required int width, required int height, required String text, required int align}) → Future<String?>
printerState() → Future<String?>
printImage(Uint8List image, int align) → Future<String?>
printQrcode({required int width, required int height, required String text}) → Future<String?>
printRaw(Uint8List data) → Future<String?>
printText(GertecText textObject) → Future<String?>
readCamera({DecodeMode decodeMode = DecodeMode.MODE_SINGLE_SCAN_CODE}) → Future<String?>
startTransaction() → Future<String?>
stopCamera() → Future<String?>
toString() → String
A string representation of this object.
inherited
wrapLine(int lines) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ GertecPrinterPlatform
The default instance of GertecPrinterPlatform to use.
getter/setter pair